#line 2 "lexer.c"

#line 4 "lexer.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

/* %not-for-header */

/* %if-c-only */
/* %if-not-reentrant */

/* %endif */
/* %endif */
/* %ok-for-header */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 37
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* %if-c++-only */
/* %endif */

/* %if-c-only */
    
/* %endif */

/* %if-c-only */

/* %endif */

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
/* %if-c-only */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>
/* %endif */

/* %if-tables-serialization */
/* %endif */
/* end standard C headers. */

/* %if-c-or-c++ */
/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

/* %endif */

/* %if-c++-only */
/* %endif */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* %not-for-header */

/* Returned upon end-of-file. */
#define YY_NULL 0
/* %ok-for-header */

/* %not-for-header */

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)
/* %ok-for-header */

/* %if-reentrant */
/* %endif */

/* %if-not-reentrant */

/* %endif */

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart(yyin  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#define YY_BUF_SIZE 16384
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

/* %if-not-reentrant */
extern yy_size_t yyleng;
/* %endif */

/* %if-c-only */
/* %if-not-reentrant */
extern FILE *yyin, *yyout;
/* %endif */
/* %endif */

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    /* Note: We specifically omit the test for yy_rule_can_match_eol because it requires
     *       access to the local variable yy_act. Since yyless() is a macro, it would break
     *       existing scanners that call yyless() from OUTSIDE yylex. 
     *       One obvious solution it to make yy_act a global. I tried that, and saw
     *       a 5% performance hit in a non-yylineno scanner, because yy_act is
     *       normally declared as a register variable-- so it is not worth it.
     */
    #define  YY_LESS_LINENO(n) \
            do { \
                int yyl;\
                for ( yyl = n; yyl < yyleng; ++yyl )\
                    if ( yytext[yyl] == '\n' )\
                        --yylineno;\
            }while(0)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
/* %if-c-only */
	FILE *yy_input_file;
/* %endif */

/* %if-c++-only */
/* %endif */

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	yy_size_t yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* %if-c-only Standard (non-C++) definition */
/* %not-for-header */

/* %if-not-reentrant */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = 0; /**< Stack as an array. */
/* %endif */
/* %ok-for-header */

/* %endif */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* %if-c-only Standard (non-C++) definition */

/* %if-not-reentrant */
/* %not-for-header */

/* yy_hold_char holds the character lost when yytext is formed. */
static char yy_hold_char;
static yy_size_t yy_n_chars;		/* number of characters read into yy_ch_buf */
yy_size_t yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char *) 0;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow yywrap()'s to do buffer switches
 * instead of setting up a fresh yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;
/* %ok-for-header */

/* %endif */

void yyrestart (FILE *input_file  );
void yy_switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE yy_create_buffer (FILE *file,int size  );
void yy_delete_buffer (YY_BUFFER_STATE b  );
void yy_flush_buffer (YY_BUFFER_STATE b  );
void yypush_buffer_state (YY_BUFFER_STATE new_buffer  );
void yypop_buffer_state (void );

static void yyensure_buffer_stack (void );
static void yy_load_buffer_state (void );
static void yy_init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER yy_flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE yy_scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE yy_scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE yy_scan_bytes (yyconst char *bytes,yy_size_t len  );

/* %endif */

void *yyalloc (yy_size_t  );
void *yyrealloc (void *,yy_size_t  );
void yyfree (void *  );

#define yy_new_buffer yy_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* %% [1.0] yytext/yyin/yyout/yy_state_type/yylineno etc. def's & init go here */
/* Begin user sect3 */

#define FLEX_DEBUG

typedef unsigned char YY_CHAR;

FILE *yyin = (FILE *) 0, *yyout = (FILE *) 0;

typedef int yy_state_type;

extern int yylineno;

int yylineno = 1;

extern char *yytext;
#define yytext_ptr yytext

/* %if-c-only Standard (non-C++) definition */

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
static void yy_fatal_error (yyconst char msg[]  );

/* %endif */

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
/* %% [2.0] code to fiddle yytext and yyleng for yymore() goes here \ */\
	yyleng = (size_t) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
/* %% [3.0] code to copy yytext_ptr to yytext[] goes here, if %array \ */\
	(yy_c_buf_p) = yy_cp;

/* %% [4.0] data tables for the DFA and the user's section 1 definitions go here */
#define YY_NUM_RULES 129
#define YY_END_OF_BUFFER 130
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[388] =
    {   0,
        0,    0,    0,    0,    0,    0,  130,  128,    6,    6,
       43,   47,   10,  128,  117,  128,    4,    4,    1,    2,
       41,  127,  127,  127,  127,  127,  127,  127,   31,  127,
      127,  127,  127,  127,  127,  127,  127,  127,  127,  127,
       32,  127,  127,   40,   14,   15,   13,   11,   74,   74,
       58,   72,   48,   73,   49,   50,   74,  129,  129,  129,
      129,    0,    0,    0,    0,    0,    0,    0,    7,    5,
        5,    9,    9,    0,    0,    0,    4,  127,  127,  127,
      127,  127,  127,  127,  127,  127,  127,  127,  127,  127,
      127,  127,  127,  127,  127,   29,  127,  127,  127,  127,

      127,  127,  127,   28,  127,   97,  127,  127,  127,  127,
       27,  127,  127,  127,  127,  127,  127,  127,   86,  127,
      127,  127,  127,  127,  127,   12,    0,   58,   58,    0,
       59,   55,   52,   56,   60,   53,   54,   57,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,   51,   71,
       75,    0,    0,   20,   20,   16,    0,    0,    0,    5,
        0,    9,   24,    8,   85,  127,  127,  127,  108,  127,
      127,  127,  127,  127,  127,  127,  127,  127,   33,  127,
      127,  127,  127,  127,  127,  127,  127,  127,   37,  127,
      127,  127,  127,  127,  127,  127,  127,  127,  123,  109,

      127,   98,  127,  127,   95,  127,  127,  127,  102,  127,
      127,  127,  127,  127,  116,  127,  127,  127,  127,  127,
      127,   59,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,   76,    0,   18,   17,   21,    0,    0,    0,
        0,    0,  127,  127,  127,  127,  127,  127,  127,  127,
      127,  127,   94,  127,   34,  127,  125,   44,  127,   78,
      127,  127,   82,  127,  101,   42,  127,  127,  115,  127,
      127,  110,   96,  127,  127,  118,  127,  127,   45,  127,
       39,  127,  127,  127,  127,  127,   79,  127,   84,  127,
      127,   70,   65,   61,   66,   69,   63,   64,   62,   68,

       67,   77,   19,   22,    0,    0,   24,   25,  127,   89,
      127,  127,  127,  127,  127,   87,   26,  127,  127,   35,
      114,    3,  127,   81,  104,  107,  127,  127,  127,   46,
      127,  124,  127,  119,  127,  127,  127,  100,  127,   83,
      105,  127,   23,    0,   99,  127,   90,  103,  127,  127,
      127,   91,  106,  127,  127,  127,  127,  127,  127,  127,
      113,  127,   30,    0,   25,  127,  126,  127,  127,  127,
       88,  127,  111,   36,  121,   80,  112,   92,  127,  127,
       38,   93,  127,  120,  127,  122,    0
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        4,    4,    2,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    5,    6,    7,    8,    8,    8,    8,    9,   10,
       11,   12,   13,    8,   14,   15,    8,   16,   17,   17,
       17,   17,   17,   17,   17,   18,   18,    8,    8,   19,
        8,   20,    8,   21,   22,   22,   23,   24,   22,   25,
       26,    8,   27,    8,   28,   29,    8,    8,    8,   30,
        8,   31,   32,    8,    8,    8,    8,    8,    8,    8,
        8,   33,    8,    8,   34,    8,   35,   36,   37,   38,

       39,   40,   41,   42,   43,   44,   45,   46,   47,   48,
       49,   50,   51,   52,   53,   54,   55,   56,   57,   58,
       59,   51,    8,   60,    8,    8,    1,   61,   61,   61,
       61,   61,   61,   61,   61,   61,   61,   61,   61,   61,
       61,   61,   61,   61,   61,   61,   61,   61,   61,   61,
       61,   61,   61,   61,   61,   61,   61,   61,   61,   61,
       61,   61,   61,   61,   61,   61,   61,   61,   61,   61,
       61,   61,   61,   61,   61,   61,   61,   61,   61,   61,
       61,   61,   61,   61,   61,   61,   61,   61,   61,   61,
       61,   62,   62,   62,   62,   62,   62,   62,   62,   62,

       62,   62,   62,   62,   62,   62,   62,   62,   62,   62,
       62,   62,   62,   62,   62,   62,   62,   62,   62,   62,
       62,   62,   62,   63,   63,   63,   63,   63,   63,   63,
       63,   63,   63,   63,   63,   63,   63,   63,   63,   64,
       64,   64,   64,   64,   64,   64,   64,   65,   65,   65,
       65,   65,   65,   65,   65
    } ;

static yyconst flex_int32_t yy_meta[66] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    2,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    1,
        4,    1,    1,    1,    4
    } ;

static yyconst flex_int16_t yy_base[393] =
    {   0,
        0,    0,   65,  130,  194,  258,  644,  645,  645,  645,
      645,  645,   74,   68,   64,   68,   77,   72,  645,  645,
      645,   53,   61,   58,   59,  585,   57,  596,   65,   65,
        0,  602,   81,   74,  100,  106,  107,   69,  108,  592,
      108,  596,  600,  645,  645,  645,  645,  628,  645,  144,
      148,  161,  645,  645,  645,  645,  322,  645,  575,  574,
      573,  624,  623,  622,  569,  568,  567,  111,  645,  645,
      151,  157,  161,  164,  168,  187,  172,    0,  121,  584,
      573,  571,  576,   24,  166,  170,  573,  172,  574,  143,
      572,  577,  584,  579,  582,  562,  576,  562,  183,  578,

      159,  167,  182,    0,  572,    0,  557,  185,  562,  554,
        0,  560,  550,  560,  568,  561,  551,  566,  551,  555,
      550,  563,  558,  558,  552,  645,  230,  236,  240,  244,
      246,  264,  645,  645,  645,  645,  645,  645,  236,  257,
      263,  266,  269,  272,  276,  279,  282,  285,  645,  645,
      645,  533,  532,  645,  583,  582,  581,  528,  527,  288,
      291,  315,  353,  357,    0,  532,  545,  546,    0,  530,
      528,  528,  538,  526,  540,  539,  540,  541,  529,  521,
      519,  533,  521,  512,  528,  531,  513,  525,    0,  518,
      516,  524,  521,  507,  522,  524,  513,  515,    0,    0,

      501,    0,  509,  515,  518,  517,  498,  509,    0,  510,
      494,  507,  507,  499,    0,  496,  485,  505,  487,  486,
      492,  266,  360,  367,  370,  373,  378,  381,  391,  399,
      402,  405,  645,  477,  645,  528,  645,  527,  474,  424,
      412,  434,  481,  485,  486,  492,  483,  490,  480,  485,
      478,  488,    0,  476,  477,  468,    0,    0,  477,    0,
      459,  455,    0,  457,    0,    0,  449,  439,    0,  454,
      434,    0,    0,  434,  443,    0,  431,  431,    0,  437,
        0,  429,  411,  429,  424,  406,    0,  409,    0,  411,
      406,  645,  645,  645,  645,  645,  645,  645,  645,  645,

      645,  645,  645,  645,  435,  294,  645,  444,  389,    0,
      394,  384,  386,  385,  388,    0,    0,  373,  375,    0,
        0,    0,  358,    0,    0,    0,  375,  353,  349,    0,
      354,    0,  347,    0,  307,  305,  293,    0,  280,    0,
        0,  287,  645,  457,    0,  286,    0,    0,  274,  272,
      269,    0,    0,  276,  223,  218,  225,  203,  202,  206,
        0,  192,    0,  467,  481,  195,    0,  186,  176,  132,
        0,  131,    0,    0,    0,    0,    0,    0,  105,   66,
        0,    0,   57,    0,   50,    0,  645,  506,  510,  514,
      517,   70

    } ;

static yyconst flex_int16_t yy_def[393] =
    {   0,
      387,    1,  388,  388,  389,  389,  387,  387,  387,  387,
      387,  387,  390,  391,  387,  387,  387,  387,  387,  387,
      387,  392,  392,  392,  392,  392,  392,  392,  392,  392,
      392,  392,  392,  392,  392,  392,  392,  392,  392,  392,
      392,  392,  392,  387,  387,  387,  387,  387,  387,  387,
      387,  387,  387,  387,  387,  387,  387,  387,  387,  387,
      387,  387,  387,  387,  387,  387,  387,  391,  387,  387,
      387,  387,  387,  387,  387,  387,  387,  392,  392,  392,
      392,  392,  392,  392,  392,  392,  392,  392,  392,  392,
      392,  392,  392,  392,  392,  392,  392,  392,  392,  392,

      392,  392,  392,  392,  392,  392,  392,  392,  392,  392,
      392,  392,  392,  392,  392,  392,  392,  392,  392,  392,
      392,  392,  392,  392,  392,  387,  387,  387,  387,  387,
      387,  387,  387,  387,  387,  387,  387,  387,  387,  387,
      387,  387,  387,  387,  387,  387,  387,  387,  387,  387,
      387,  387,  387,  387,  387,  387,  387,  387,  387,  387,
      387,  387,  387,  387,  392,  392,  392,  392,  392,  392,
      392,  392,  392,  392,  392,  392,  392,  392,  392,  392,
      392,  392,  392,  392,  392,  392,  392,  392,  392,  392,
      392,  392,  392,  392,  392,  392,  392,  392,  392,  392,

      392,  392,  392,  392,  392,  392,  392,  392,  392,  392,
      392,  392,  392,  392,  392,  392,  392,  392,  392,  392,
      392,  387,  387,  387,  387,  387,  387,  387,  387,  387,
      387,  387,  387,  387,  387,  387,  387,  387,  387,  387,
      387,  387,  392,  392,  392,  392,  392,  392,  392,  392,
      392,  392,  392,  392,  392,  392,  392,  392,  392,  392,
      392,  392,  392,  392,  392,  392,  392,  392,  392,  392,
      392,  392,  392,  392,  392,  392,  392,  392,  392,  392,
      392,  392,  392,  392,  392,  392,  392,  392,  392,  392,
      392,  387,  387,  387,  387,  387,  387,  387,  387,  387,

      387,  387,  387,  387,  387,  387,  387,  387,  392,  392,
      392,  392,  392,  392,  392,  392,  392,  392,  392,  392,
      392,  392,  392,  392,  392,  392,  392,  392,  392,  392,
      392,  392,  392,  392,  392,  392,  392,  392,  392,  392,
      392,  392,  387,  387,  392,  392,  392,  392,  392,  392,
      392,  392,  392,  392,  392,  392,  392,  392,  392,  392,
      392,  392,  392,  387,  387,  392,  392,  392,  392,  392,
      392,  392,  392,  392,  392,  392,  392,  392,  392,  392,
      392,  392,  392,  392,  392,  392,    0,  387,  387,  387,
      387,  387

    } ;

static yyconst flex_int16_t yy_nxt[711] =
    {   0,
        8,    9,   10,    9,    9,   11,   12,    8,   13,   14,
        8,   15,   16,   16,    8,   17,   18,   18,   19,   20,
        8,    8,    8,    8,    8,    8,    8,    8,    8,    8,
        8,    8,    8,   21,   22,   23,   24,   25,   26,   27,
       28,   29,   30,   31,   32,   33,   34,   31,   35,   36,
       31,   37,   38,   39,   40,   41,   42,   43,   31,   44,
        8,    8,    8,    8,    8,   45,   45,   46,   45,  171,
       69,  172,   78,   48,   62,   62,   62,   62,   69,   70,
       71,   71,   64,   72,   73,   73,   74,   77,   77,   77,
       79,   74,   75,   75,   75,   81,   83,   85,   80,   88,

       91,   86,  386,   92,  385,   89,   84,  115,  102,   82,
      116,   95,   96,   69,   93,   99,  103,   94,   97,  100,
      104,   69,  117,  101,  384,   45,   45,   45,   45,   45,
       45,   45,   46,   45,   76,   65,   66,   67,   48,  105,
      108,  112,  118,  121,  109,  127,  128,  106,  127,  129,
      128,  110,  129,  383,  107,  113,  119,  122,  165,  111,
      123,  114,  127,  128,  166,  127,  160,  160,  160,  382,
      381,   74,   75,   75,   75,   74,  162,  162,  162,  163,
      163,  163,   74,   75,   75,   75,   74,   77,   77,   77,
       45,   45,   45,   45,   45,   50,   51,  182,   52,  196,

       53,  183,  164,  164,  164,  173,  197,   54,  164,  164,
      164,  164,   55,   56,  161,  174,  175,  179,  192,  200,
      198,  176,  177,  180,  199,  204,   57,  380,  379,  201,
      193,  127,  128,  378,  127,  194,  205,  129,  128,  377,
      129,  129,  128,  376,  129,  130,  131,  222,  130,  375,
      222,  223,  223,  223,   58,   59,   60,   61,   58,   50,
       51,  374,   52,  373,   53,  130,  131,  222,  130,  372,
      222,   54,  224,  224,  224,  371,   55,   56,  225,  225,
      225,  226,  226,  226,  227,  227,  227,  228,  228,  228,
       57,  229,  229,  229,  230,  230,  230,  231,  231,  231,

      232,  232,  232,  160,  160,  160,  240,  240,  240,  307,
      307,  307,  240,  240,  240,  240,  370,  369,   58,   59,
       60,   61,   58,  130,  131,  368,  132,  367,  133,   74,
      162,  162,  162,  366,  363,  134,  362,  135,  135,  361,
      136,  137,  138,  360,  139,  140,  141,  142,  143,  144,
      145,  146,  147,  148,  149,  359,  150,  150,  150,  150,
      150,  150,  150,  150,  150,  150,  150,  150,  163,  163,
      163,  242,  164,  164,  164,  223,  223,  223,  164,  164,
      164,  164,  224,  224,  224,  225,  225,  225,  226,  226,
      226,  241,  292,  227,  227,  227,  228,  228,  228,  293,

      358,  357,  294,  356,  355,  295,  229,  229,  229,  354,
      296,  353,  352,  297,  230,  230,  230,  231,  231,  231,
      232,  232,  232,  298,  306,  306,  351,  307,  307,  307,
      350,  299,  349,  348,  300,  347,  346,  301,  242,  240,
      240,  240,  345,  343,  342,  240,  240,  240,  240,  308,
      308,  308,  341,  340,  339,  308,  308,  308,  308,  308,
      308,  308,  338,  337,  336,  308,  308,  308,  308,  364,
      364,  335,  365,  365,  365,  334,  333,  332,  365,  365,
      365,  365,  365,  365,  365,  331,  330,  329,  365,  365,
      365,  365,  328,  327,  326,  325,  365,  365,  365,  324,

      323,  344,  365,  365,  365,  365,   47,   47,   47,   47,
       49,   49,   49,   49,   63,   63,   63,   68,  322,   68,
       68,  321,  320,  319,  318,  317,  316,  315,  314,  313,
      312,  311,  310,  309,  305,  304,  303,  302,  291,  290,
      289,  288,  287,  286,  285,  284,  283,  282,  281,  280,
      279,  278,  277,  276,  275,  274,  273,  272,  271,  270,
      269,  268,  267,  266,  265,  264,  263,  262,  261,  260,
      259,  258,  257,  256,  255,  254,  253,  252,  251,  250,
      249,  248,  247,  246,  245,  244,  243,  239,  238,  237,
      236,  235,  234,  233,  221,  220,  219,  218,  217,  216,

      215,  214,  213,  212,  211,  210,  209,  208,  207,  206,
      203,  202,  195,  191,  190,  189,  188,  187,  186,  185,
      184,  181,  178,  170,  169,  168,  167,  159,  158,  157,
      156,  155,  154,  153,  152,  151,  126,  125,  124,  120,
       98,   90,   87,  387,    7,  387,  387,  387,  387,  387,
      387,  387,  387,  387,  387,  387,  387,  387,  387,  387,
      387,  387,  387,  387,  387,  387,  387,  387,  387,  387,
      387,  387,  387,  387,  387,  387,  387,  387,  387,  387,
      387,  387,  387,  387,  387,  387,  387,  387,  387,  387,
      387,  387,  387,  387,  387,  387,  387,  387,  387,  387,

      387,  387,  387,  387,  387,  387,  387,  387,  387,  387
    } ;

static yyconst flex_int16_t yy_chk[711] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    3,    3,    3,    3,   84,
       14,   84,  392,    3,   13,   13,   13,   13,   14,   15,
       15,   15,   13,   16,   16,   16,   18,   18,   18,   18,
       22,   17,   17,   17,   17,   23,   24,   25,   22,   27,

       29,   25,  385,   29,  383,   27,   24,   38,   34,   23,
       38,   30,   30,   68,   29,   33,   34,   29,   30,   33,
       34,   68,   38,   33,  380,    3,    3,    3,    3,    3,
        4,    4,    4,    4,   17,   13,   13,   13,    4,   35,
       36,   37,   39,   41,   36,   50,   50,   35,   50,   51,
       51,   36,   51,  379,   35,   37,   39,   41,   79,   36,
       41,   37,   52,   52,   79,   52,   71,   71,   71,  372,
      370,   72,   72,   72,   72,   73,   73,   73,   73,   74,
       74,   74,   75,   75,   75,   75,   77,   77,   77,   77,
        4,    4,    4,    4,    4,    5,    5,   90,    5,  101,

        5,   90,   76,   76,   76,   85,  101,    5,   76,   76,
       76,   76,    5,    5,   72,   85,   86,   88,   99,  103,
      102,   86,   86,   88,  102,  108,    5,  369,  368,  103,
       99,  127,  127,  366,  127,   99,  108,  128,  128,  362,
      128,  129,  129,  360,  129,  130,  130,  131,  130,  359,
      131,  139,  139,  139,    5,    5,    5,    5,    5,    6,
        6,  358,    6,  357,    6,  132,  132,  222,  132,  356,
      222,    6,  140,  140,  140,  355,    6,    6,  141,  141,
      141,  142,  142,  142,  143,  143,  143,  144,  144,  144,
        6,  145,  145,  145,  146,  146,  146,  147,  147,  147,

      148,  148,  148,  160,  160,  160,  161,  161,  161,  306,
      306,  306,  161,  161,  161,  161,  354,  351,    6,    6,
        6,    6,    6,   57,   57,  350,   57,  349,   57,  162,
      162,  162,  162,  346,  342,   57,  339,   57,   57,  337,
       57,   57,   57,  336,   57,   57,   57,   57,   57,   57,
       57,   57,   57,   57,   57,  335,   57,   57,   57,   57,
       57,   57,   57,   57,   57,   57,   57,   57,  163,  163,
      163,  164,  164,  164,  164,  223,  223,  223,  164,  164,
      164,  164,  224,  224,  224,  225,  225,  225,  226,  226,
      226,  163,  223,  227,  227,  227,  228,  228,  228,  224,

      333,  331,  225,  329,  328,  226,  229,  229,  229,  327,
      227,  323,  319,  228,  230,  230,  230,  231,  231,  231,
      232,  232,  232,  229,  241,  241,  318,  241,  241,  241,
      315,  230,  314,  313,  231,  312,  311,  232,  240,  240,
      240,  240,  309,  305,  291,  240,  240,  240,  240,  242,
      242,  242,  290,  288,  286,  242,  242,  242,  242,  308,
      308,  308,  285,  284,  283,  308,  308,  308,  308,  344,
      344,  282,  344,  344,  344,  280,  278,  277,  344,  344,
      344,  344,  364,  364,  364,  275,  274,  271,  364,  364,
      364,  364,  270,  268,  267,  264,  365,  365,  365,  262,

      261,  308,  365,  365,  365,  365,  388,  388,  388,  388,
      389,  389,  389,  389,  390,  390,  390,  391,  259,  391,
      391,  256,  255,  254,  252,  251,  250,  249,  248,  247,
      246,  245,  244,  243,  239,  238,  236,  234,  221,  220,
      219,  218,  217,  216,  214,  213,  212,  211,  210,  208,
      207,  206,  205,  204,  203,  201,  198,  197,  196,  195,
      194,  193,  192,  191,  190,  188,  187,  186,  185,  184,
      183,  182,  181,  180,  179,  178,  177,  176,  175,  174,
      173,  172,  171,  170,  168,  167,  166,  159,  158,  157,
      156,  155,  153,  152,  125,  124,  123,  122,  121,  120,

      119,  118,  117,  116,  115,  114,  113,  112,  110,  109,
      107,  105,  100,   98,   97,   96,   95,   94,   93,   92,
       91,   89,   87,   83,   82,   81,   80,   67,   66,   65,
       64,   63,   62,   61,   60,   59,   48,   43,   42,   40,
       32,   28,   26,    7,  387,  387,  387,  387,  387,  387,
      387,  387,  387,  387,  387,  387,  387,  387,  387,  387,
      387,  387,  387,  387,  387,  387,  387,  387,  387,  387,
      387,  387,  387,  387,  387,  387,  387,  387,  387,  387,
      387,  387,  387,  387,  387,  387,  387,  387,  387,  387,
      387,  387,  387,  387,  387,  387,  387,  387,  387,  387,

      387,  387,  387,  387,  387,  387,  387,  387,  387,  387
    } ;

/* Table of booleans, true if rule could match eol. */
static yyconst flex_int32_t yy_rule_can_match_eol[130] =
    {   0,
0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 
    1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0,     };

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int yy_flex_debug;
int yy_flex_debug = 1;

static yyconst flex_int16_t yy_rule_linenum[129] =
    {   0,
      170,  171,  172,  173,  174,  175,  176,  178,  180,  182,
      184,  185,  186,  187,  188,  193,  194,  195,  196,  197,
      198,  199,  200,  202,  204,  206,  207,  208,  209,  211,
      212,  213,  215,  216,  217,  219,  220,  222,  224,  225,
      226,  228,  229,  231,  232,  233,  235,  238,  240,  241,
      243,  244,  245,  246,  247,  248,  249,  251,  252,  254,
      256,  257,  258,  259,  260,  261,  262,  263,  264,  267,
      269,  270,  271,  273,  274,  275,  276,  279,  280,  281,
      283,  284,  285,  286,  287,  288,  289,  291,  292,  293,
      294,  296,  298,  300,  302,  304,  306,  307,  309,  311,

      312,  313,  314,  316,  317,  318,  320,  321,  322,  324,
      326,  328,  330,  331,  332,  333,  334,  336,  338,  340,
      341,  343,  345,  347,  349,  351,  353,  354
    } ;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *yytext;
#line 1 "lexer.l"
/*533:*/
#line 3 "lexer.l"
	#line 11040 "format.w"
	
#include "hibasetypes.h"
#include "hierror.h"
#include "hiformat.h"
#include "hiput.h"

	/*445:*/
#ifdef DEBUG
#define  YYDEBUG 1
extern int yydebug;
#else
#define YYDEBUG 0
#endif
	/*:445*/
#include "hiparser.h"

	/*23:*/
#define SCAN_UDEC(S) yylval.u= strtoul(S,NULL,10)
	/*:23*/	/*26:*/
#define SCAN_HEX(S) yylval.u= strtoul(S,NULL,16)
	/*:26*/	/*29:*/
#define SCAN_DEC(S) yylval.i= strtol(S,NULL,10)
	/*:29*/	/*32:*/
#define MAX_STR    (1<<10) 
static char str_buffer[MAX_STR];
static int str_length;
#define STR_START      (str_length= 0)
#define STR_PUT(C) (str_buffer[str_length++]= (C))
#define STR_ADD(C) STR_PUT(C);RNG("String length",str_length,0,MAX_STR-1)
#define STR_END        str_buffer[str_length]= 0
#define SCAN_STR       yylval.s= str_buffer
	/*:32*/	/*41:*/
#define SCAN_UTF8_1(S)   yylval.u= ((S)[0]&0x7F)
	/*:41*/	/*43:*/
#define SCAN_UTF8_2(S)   yylval.u= (((S)[0]&0x1F)<<6)+((S)[1]&0x3F)
	/*:43*/	/*45:*/
#define SCAN_UTF8_3(S)   yylval.u= (((S)[0]&0x0F)<<12)+(((S)[1]&0x3F)<<6)+((S)[2]&0x3F)
	/*:45*/	/*47:*/
#define SCAN_UTF8_4(S)   yylval.u= (((S)[0]&0x03)<<18)+(((S)[1]&0x3F)<<12)+(((S)[2]&0x3F)<<6)+((S)[3]&0x3F)
	/*:47*/	/*58:*/
#define SCAN_DECFLOAT       yylval.f= atof(yytext)
	/*:58*/	/*61:*/
#define SCAN_HEXFLOAT       yylval.f= xtof(yytext)
	/*:61*/	/*153:*/
#define SCAN_REF(K) yylval.rf.k= K; yylval.rf.n= atoi(yytext+2)
static int scan_level= 0;
#define SCAN_START          yy_push_state(INITIAL);if (1==scan_level++) hpos0= hpos;
#define SCAN_END            if (scan_level--) yy_pop_state(); else QUIT("Too many '>' in line %d",yylineno)
#define SCAN_TXT_START      BEGIN(TXT)
#define SCAN_TXT_END        BEGIN(INITIAL)
	/*:153*/
	/*62:*/

float64_t xtof(char*x)
{
	#line 1388 "format.w"
	int sign,digits,exp;
	uint64_t mantissa= 0;
	DBG(DBGFLOAT,"converting %s:\n",x);
		/*63:*/
	if(*x=='-'){sign= -1;x++;}
	else if(*x=='+'){sign= +1;x++;}
	else sign= +1;
	DBG(DBGFLOAT,"\tsign=%d\n",sign);
		/*:63*/
	x= x+2;
		/*64:*/
	digits= 0;
	while(*x=='0')x++;
	while(*x!='.')
	{mantissa= mantissa<<4;
	if(*x<'A')mantissa= mantissa+*x-'0';
	else mantissa= mantissa+*x-'A'+10;
	x++;
	digits++;
	}
	x++;
	exp= 0;
	while(*x!=0&&*x!='x')
	{mantissa= mantissa<<4;
	exp= exp-4;
	if(*x<'A')mantissa= mantissa+*x-'0';
	else mantissa= mantissa+*x-'A'+10;
	x++;
	digits++;
	}
	DBG(DBGFLOAT,"\tdigits=%d mantissa=0x%"PRIx64", exp=%d\n",digits,mantissa,exp);
		/*:64*/
		/*65:*/
	if(mantissa==0)return 0.0;
	{int s;
	s= digits-DBL_M_BITS/4;
	if(s>1)
	mantissa= mantissa>>(4*(s-1));
	else if(s<1)
	mantissa= mantissa<<(4*(1-s));
	exp= exp+4*(digits-1);
	DBG(DBGFLOAT,"\tdigits=%d mantissa=0x%"PRIx64", exp=%d\n",digits,mantissa,exp);
	while((mantissa>>DBL_M_BITS)>1){mantissa= mantissa>>1;exp++;}
	DBG(DBGFLOAT,"\tdigits=%d mantissa=0x%"PRIx64", exp=%d\n",digits,mantissa,exp);
	mantissa= mantissa&~((uint64_t)1<<DBL_M_BITS);
	DBG(DBGFLOAT,"\tdigits=%d mantissa=0x%"PRIx64", exp=%d\n",digits,mantissa,exp);
	}
		/*:65*/
		/*66:*/
	if(*x=='x')
	{int s;
	x++;
	if(*x=='-'){s= -1;x++;}
	else if(*x=='+'){s= +1;x++;}
	else s= +1;
	DBG(DBGFLOAT,"\texpsign=%d\n",s);
	DBG(DBGFLOAT,"\texp=%d\n",exp);
	while(*x!=0)
	{if(*x<'A')exp= exp+4*s*(*x-'0');
	else exp= exp+4*s*(*x-'A'+10);
	x++;
	DBG(DBGFLOAT,"\texp=%d\n",exp);
	}
	}
	RNG("Floating point exponent",exp,-DBL_EXCESS,DBL_EXCESS);
		/*:66*/
		/*67:*/
	{union{float64_t d;uint64_t bits;}u;
	if(sign<0)sign= 1;else sign= 0;
	exp= exp+DBL_EXCESS;
	u.bits= ((uint64_t)sign<<63)
		|((uint64_t)exp<<DBL_M_BITS)	|mantissa;
	DBG(DBGFLOAT," return %f\n",u.d);
	return u.d;
	}
		/*:67*/
	}
	/*:62*/
int yywrap(void){
	#line 11051 "format.w"
	return 1;}
#ifdef _MSC_VER
#pragma  warning( disable : 4267)
#endif

#define YY_NO_UNISTD_H 1
#define YY_NO_INPUT 1
/*24:*/
/*:24*/	/*33:*/

/*:33*/	/*40:*/
/*:40*/	/*42:*/
/*:42*/	/*44:*/
/*:44*/	/*46:*/
/*:46*/	/*150:*/

/*:150*/
#line 1019 "lexer.c"

#define INITIAL 0
#define STR 1
#define TXT 2

#ifndef YY_NO_UNISTD_H
/* Special case for "hiunistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
/* %if-c-only */
#include <unistd.h>
/* %endif */
/* %if-c++-only */
/* %endif */
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

/* %if-c-only Reentrant structure and macros (non-C++). */
/* %if-reentrant */
/* %if-c-only */

static int yy_init_globals (void );

/* %endif */
/* %if-reentrant */
/* %endif */
/* %endif End reentrant structures and macros. */

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy (void );

int yyget_debug (void );

void yyset_debug (int debug_flag  );

YY_EXTRA_TYPE yyget_extra (void );

void yyset_extra (YY_EXTRA_TYPE user_defined  );

FILE *yyget_in (void );

void yyset_in  (FILE * in_str  );

FILE *yyget_out (void );

void yyset_out  (FILE * out_str  );

yy_size_t yyget_leng (void );

char *yyget_text (void );

int yyget_lineno (void );

void yyset_lineno (int line_number  );

/* %if-bison-bridge */
/* %endif */

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap (void );
#else
extern int yywrap (void );
#endif
#endif

/* %not-for-header */

/* %ok-for-header */

/* %endif */

#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT
/* %if-c-only Standard (non-C++) definition */
/* %not-for-header */

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif
/* %ok-for-header */

/* %endif */
#endif

/* %if-c-only */

        static int yy_start_stack_ptr = 0;
        static int yy_start_stack_depth = 0;
        static int *yy_start_stack = NULL;
    
    static void yy_push_state (int new_state );
    
    static void yy_pop_state (void );
    
/* %endif */

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#define YY_READ_BUF_SIZE 8192
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* %if-c-only Standard (non-C++) definition */
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, yyleng, 1, yyout )) {} } while (0)
/* %endif */
/* %if-c++-only C++ definition */
/* %endif */
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
/* %% [5.0] fread()/read() definition of YY_INPUT goes here unless we're doing C++ \ */\
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, yyin))==0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\
/* %if-c++-only C++ definition \ */\
/* %endif */

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
/* %if-c-only */
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
/* %endif */
/* %if-c++-only */
/* %endif */
#endif

/* %if-tables-serialization structures and prototypes */
/* %not-for-header */

/* %ok-for-header */

/* %not-for-header */

/* %tables-yydmap generated elements */
/* %endif */
/* end tables serialization structures and prototypes */

/* %ok-for-header */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1
/* %if-c-only Standard (non-C++) definition */

extern int yylex (void);

#define YY_DECL int yylex (void)
/* %endif */
/* %if-c++-only C++ definition */
/* %endif */
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

/* %% [6.0] YY_RULE_SETUP definition goes here */
#define YY_RULE_SETUP \
	YY_USER_ACTION

/* %not-for-header */

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    
/* %% [7.0] user's declarations go here */
#line 167 "lexer.l"


	/*3:*/
#line 1273 "lexer.c"

	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
/* %if-c-only */
			yyin = stdin;
/* %endif */
/* %if-c++-only */
/* %endif */

		if ( ! yyout )
/* %if-c-only */
			yyout = stdout;
/* %endif */
/* %if-c++-only */
/* %endif */

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer(yyin,YY_BUF_SIZE );
		}

		yy_load_buffer_state( );
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
/* %% [8.0] yymore()-related code goes here */
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

/* %% [9.0] code to set up and find next match goes here */
		yy_current_state = (yy_start);
yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 388 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			++yy_cp;
			}
		while ( yy_current_state != 387 );
		yy_cp = (yy_last_accepting_cpos);
		yy_current_state = (yy_last_accepting_state);

yy_find_action:
/* %% [10.0] code to find the action number goes here */
		yy_act = yy_accept[yy_current_state];

		YY_DO_BEFORE_ACTION;

/* %% [11.0] code for yylineno update goes here */

		if ( yy_act != YY_END_OF_BUFFER && yy_rule_can_match_eol[yy_act] )
			{
			int yyl;
			for ( yyl = 0; yyl < yyleng; ++yyl )
				if ( yytext[yyl] == '\n' )
					   
    yylineno++;
;
			}

do_action:	/* This label is used only to access EOF actions. */

/* %% [12.0] debug code goes here */
		if ( yy_flex_debug )
			{
			if ( yy_act == 0 )
				fprintf( stderr, "--scanner backing up\n" );
			else if ( yy_act < 129 )
				fprintf( stderr, "--accepting rule at line %ld (\"%s\")\n",
				         (long)yy_rule_linenum[yy_act], yytext );
			else if ( yy_act == 129 )
				fprintf( stderr, "--accepting default rule (\"%s\")\n",
				         yytext );
			else if ( yy_act == 130 )
				fprintf( stderr, "--(end of buffer or a NUL)\n" );
			else
				fprintf( stderr, "--EOF (start condition %d)\n", YY_START );
			}

		switch ( yy_act )
	{ /* beginning of action switch */
/* %% [13.0] actions go here */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 170 "lexer.l"
SCAN_START;return START;
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 171 "lexer.l"
SCAN_END;return END;
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 172 "lexer.l"
return GLYPH;
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 173 "lexer.l"
SCAN_UDEC(yytext);return UNSIGNED;
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 174 "lexer.l"
SCAN_UDEC(yytext+1);return REFERENCE;
	YY_BREAK
case 6:
/* rule 6 can match eol */
YY_RULE_SETUP
#line 175 "lexer.l"
;
	YY_BREAK
case 7:
/* rule 7 can match eol */
YY_RULE_SETUP
#line 176 "lexer.l"
;
	YY_BREAK
/*:3*/	/*25:*/
case 8:
YY_RULE_SETUP
#line 178 "lexer.l"
SCAN_HEX(yytext+2);return UNSIGNED;
	YY_BREAK
/*:25*/	/*28:*/
case 9:
YY_RULE_SETUP
#line 180 "lexer.l"
SCAN_DEC(yytext);return SIGNED;
	YY_BREAK
/*:28*/	/*35:*/
case 10:
YY_RULE_SETUP
#line 182 "lexer.l"
STR_START;BEGIN(STR);
	YY_BREAK

case 11:
YY_RULE_SETUP
#line 184 "lexer.l"
STR_END;SCAN_STR;BEGIN(INITIAL);return STRING;
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 185 "lexer.l"
STR_ADD('\'');
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 186 "lexer.l"
STR_ADD(yytext[0]);
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 187 "lexer.l"
RNG("String character",yytext[0],0x20,0x7E);
	YY_BREAK
case 15:
/* rule 15 can match eol */
YY_RULE_SETUP
#line 188 "lexer.l"
QUIT("Unterminated String in line %d",yylineno);
	YY_BREAK

/*:35*/	/*49:*/
case 16:
YY_RULE_SETUP
#line 193 "lexer.l"
STR_START;STR_PUT('\'');BEGIN(STR);
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 194 "lexer.l"
SCAN_UTF8_1(yytext+1);return CHARCODE;
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 195 "lexer.l"
STR_START;STR_PUT(yytext[1]);STR_PUT('\'');BEGIN(STR);
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 196 "lexer.l"
STR_START;STR_PUT('\'');STR_PUT('\'');BEGIN(STR);
	YY_BREAK
case 20:
/* rule 20 can match eol */
YY_RULE_SETUP
#line 197 "lexer.l"
SCAN_UTF8_1(yytext+1);return CHARCODE;
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 198 "lexer.l"
SCAN_UTF8_2(yytext+1);return CHARCODE;
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 199 "lexer.l"
SCAN_UTF8_3(yytext+1);return CHARCODE;
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 200 "lexer.l"
SCAN_UTF8_4(yytext+1);return CHARCODE;
	YY_BREAK
/*:49*/	/*56:*/
case 24:
YY_RULE_SETUP
#line 202 "lexer.l"
SCAN_DECFLOAT;return FPNUM;
	YY_BREAK
/*:56*/	/*60:*/
case 25:
YY_RULE_SETUP
#line 204 "lexer.l"
SCAN_HEXFLOAT;return FPNUM;
	YY_BREAK
/*:60*/	/*81:*/
case 26:
YY_RULE_SETUP
#line 206 "lexer.l"
return DIMEN;
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 207 "lexer.l"
return PT;
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 208 "lexer.l"
return MM;
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 209 "lexer.l"
return INCH;
	YY_BREAK
/*:81*/	/*89:*/
case 30:
YY_RULE_SETUP
#line 211 "lexer.l"
return XDIMEN;
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 212 "lexer.l"
return H;
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 213 "lexer.l"
return V;
	YY_BREAK
/*:89*/	/*100:*/
case 33:
YY_RULE_SETUP
#line 215 "lexer.l"
return FIL;
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 216 "lexer.l"
return FILL;
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 217 "lexer.l"
return FILLL;
	YY_BREAK
/*:100*/	/*104:*/
case 36:
YY_RULE_SETUP
#line 219 "lexer.l"
return PENALTY;
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 220 "lexer.l"
return INTEGER;
	YY_BREAK
/*:104*/	/*110:*/
case 38:
YY_RULE_SETUP
#line 222 "lexer.l"
return LANGUAGE;
	YY_BREAK
/*:110*/	/*116:*/
case 39:
YY_RULE_SETUP
#line 224 "lexer.l"
return RULE;
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 225 "lexer.l"
return RUNNING;
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 226 "lexer.l"
return RUNNING;
	YY_BREAK
/*:116*/	/*125:*/
case 42:
YY_RULE_SETUP
#line 228 "lexer.l"
return KERN;
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 229 "lexer.l"
return EXPLICIT;
	YY_BREAK
/*:125*/	/*134:*/
case 44:
YY_RULE_SETUP
#line 231 "lexer.l"
return GLUE;
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 232 "lexer.l"
return PLUS;
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 233 "lexer.l"
return MINUS;
	YY_BREAK
/*:134*/	/*152:*/
case 47:
YY_RULE_SETUP
#line 235 "lexer.l"
SCAN_TXT_START;return TXT_START;
	YY_BREAK

case 48:
YY_RULE_SETUP
#line 238 "lexer.l"
SCAN_TXT_END;return TXT_END;
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 240 "lexer.l"
SCAN_START;return START;
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 241 "lexer.l"
QUIT("> not allowed in text mode");
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 243 "lexer.l"
yylval.u= '\\';return TXT_CC;
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 244 "lexer.l"
yylval.u= '"';return TXT_CC;
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 245 "lexer.l"
yylval.u= '<';return TXT_CC;
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 246 "lexer.l"
yylval.u= '>';return TXT_CC;
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 247 "lexer.l"
yylval.u= ' ';return TXT_CC;
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 248 "lexer.l"
yylval.u= '-';return TXT_CC;
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 249 "lexer.l"
return TXT_IGNORE;
	YY_BREAK
case 58:
/* rule 58 can match eol */
YY_RULE_SETUP
#line 251 "lexer.l"
return TXT_FONT_GLUE;
	YY_BREAK
case 59:
/* rule 59 can match eol */
YY_RULE_SETUP
#line 252 "lexer.l"
;
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 254 "lexer.l"
yylval.u= yytext[1]-'0';return TXT_FONT;
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 256 "lexer.l"
SCAN_REF(font_kind);return TXT_GLOBAL;
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 257 "lexer.l"
SCAN_REF(penalty_kind);return TXT_GLOBAL;
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 258 "lexer.l"
SCAN_REF(kern_kind);return TXT_GLOBAL;
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 259 "lexer.l"
SCAN_REF(ligature_kind);return TXT_GLOBAL;
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 260 "lexer.l"
SCAN_REF(disc_kind);return TXT_GLOBAL;
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 261 "lexer.l"
SCAN_REF(glue_kind);return TXT_GLOBAL;
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 262 "lexer.l"
SCAN_REF(language_kind);return TXT_GLOBAL;
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 263 "lexer.l"
SCAN_REF(rule_kind);return TXT_GLOBAL;
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 264 "lexer.l"
SCAN_REF(image_kind);return TXT_GLOBAL;
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 267 "lexer.l"
SCAN_UDEC(yytext+2);return TXT_CC;
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 269 "lexer.l"
yylval.u= yytext[1]-'a';return TXT_LOCAL;
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 270 "lexer.l"
return TXT_FONT_GLUE;
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 271 "lexer.l"
return TXT_FONT_HYPHEN;
	YY_BREAK
case 74:
/* rule 74 can match eol */
YY_RULE_SETUP
#line 273 "lexer.l"
SCAN_UTF8_1(yytext);return TXT_CC;
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 274 "lexer.l"
SCAN_UTF8_2(yytext);return TXT_CC;
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 275 "lexer.l"
SCAN_UTF8_3(yytext);return TXT_CC;
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 276 "lexer.l"
SCAN_UTF8_4(yytext);return TXT_CC;
	YY_BREAK

/*:152*/	/*162:*/
case 78:
YY_RULE_SETUP
#line 279 "lexer.l"
return HBOX;
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 280 "lexer.l"
return VBOX;
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 281 "lexer.l"
return SHIFTED;
	YY_BREAK
/*:162*/	/*170:*/
case 81:
YY_RULE_SETUP
#line 283 "lexer.l"
return HPACK;
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 284 "lexer.l"
return HSET;
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 285 "lexer.l"
return VPACK;
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 286 "lexer.l"
return VSET;
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 287 "lexer.l"
return ADD;
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 288 "lexer.l"
return TO;
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 289 "lexer.l"
return DEPTH;
	YY_BREAK
/*:170*/	/*175:*/
case 88:
YY_RULE_SETUP
#line 291 "lexer.l"
return LEADERS;
	YY_BREAK
case 89:
YY_RULE_SETUP
#line 292 "lexer.l"
return ALIGN;
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 293 "lexer.l"
return CENTER;
	YY_BREAK
case 91:
YY_RULE_SETUP
#line 294 "lexer.l"
return EXPAND;
	YY_BREAK
/*:175*/	/*182:*/
case 92:
YY_RULE_SETUP
#line 296 "lexer.l"
return BASELINE;
	YY_BREAK
/*:182*/	/*189:*/
case 93:
YY_RULE_SETUP
#line 298 "lexer.l"
return LIGATURE;
	YY_BREAK
/*:189*/	/*197:*/
case 94:
YY_RULE_SETUP
#line 300 "lexer.l"
return DISC;
	YY_BREAK
/*:197*/	/*205:*/
case 95:
YY_RULE_SETUP
#line 302 "lexer.l"
return PAR;
	YY_BREAK
/*:205*/	/*210:*/
case 96:
YY_RULE_SETUP
#line 304 "lexer.l"
return MATH;
	YY_BREAK
/*:210*/	/*215:*/
case 97:
YY_RULE_SETUP
#line 306 "lexer.l"
return ON;
	YY_BREAK
case 98:
YY_RULE_SETUP
#line 307 "lexer.l"
return OFF;
	YY_BREAK
/*:215*/	/*219:*/
case 99:
YY_RULE_SETUP
#line 309 "lexer.l"
return ADJUST;
	YY_BREAK
/*:219*/	/*223:*/
case 100:
YY_RULE_SETUP
#line 311 "lexer.l"
return TABLE;
	YY_BREAK
case 101:
YY_RULE_SETUP
#line 312 "lexer.l"
return ITEM;
	YY_BREAK
case 102:
YY_RULE_SETUP
#line 313 "lexer.l"
return ITEM;
	YY_BREAK
case 103:
YY_RULE_SETUP
#line 314 "lexer.l"
return ITEM;
	YY_BREAK
/*:223*/	/*230:*/
case 104:
YY_RULE_SETUP
#line 316 "lexer.l"
return IMAGE;
	YY_BREAK
case 105:
YY_RULE_SETUP
#line 317 "lexer.l"
return WIDTH;
	YY_BREAK
case 106:
YY_RULE_SETUP
#line 318 "lexer.l"
return HEIGHT;
	YY_BREAK
/*:230*/	/*255:*/
case 107:
YY_RULE_SETUP
#line 320 "lexer.l"
return LABEL;
	YY_BREAK
case 108:
YY_RULE_SETUP
#line 321 "lexer.l"
return BOT;
	YY_BREAK
case 109:
YY_RULE_SETUP
#line 322 "lexer.l"
return MID;
	YY_BREAK
/*:255*/	/*269:*/
case 110:
YY_RULE_SETUP
#line 324 "lexer.l"
return LINK;
	YY_BREAK
/*:269*/	/*279:*/
case 111:
YY_RULE_SETUP
#line 326 "lexer.l"
return OUTLINE;
	YY_BREAK
/*:279*/	/*286:*/
case 112:
YY_RULE_SETUP
#line 328 "lexer.l"
return UNKNOWN;
	YY_BREAK
/*:286*/	/*295:*/
case 113:
YY_RULE_SETUP
#line 330 "lexer.l"
if(section_no==1)return STREAMDEF;else return STREAM;
	YY_BREAK
case 114:
YY_RULE_SETUP
#line 331 "lexer.l"
return FIRST;
	YY_BREAK
case 115:
YY_RULE_SETUP
#line 332 "lexer.l"
return LAST;
	YY_BREAK
case 116:
YY_RULE_SETUP
#line 333 "lexer.l"
return TOP;
	YY_BREAK
case 117:
YY_RULE_SETUP
#line 334 "lexer.l"
return NOREFERENCE;
	YY_BREAK
/*:295*/	/*305:*/
case 118:
YY_RULE_SETUP
#line 336 "lexer.l"
return PAGE;
	YY_BREAK
/*:305*/	/*313:*/
case 119:
YY_RULE_SETUP
#line 338 "lexer.l"
return RANGE;
	YY_BREAK
/*:313*/	/*340:*/
case 120:
YY_RULE_SETUP
#line 340 "lexer.l"
return DIRECTORY;
	YY_BREAK
case 121:
YY_RULE_SETUP
#line 341 "lexer.l"
return SECTION;
	YY_BREAK
/*:340*/	/*361:*/
case 122:
YY_RULE_SETUP
#line 343 "lexer.l"
return DEFINITIONS;
	YY_BREAK
/*:361*/	/*369:*/
case 123:
YY_RULE_SETUP
#line 345 "lexer.l"
return MAX;
	YY_BREAK
/*:369*/	/*384:*/
case 124:
YY_RULE_SETUP
#line 347 "lexer.l"
return PARAM;
	YY_BREAK
/*:384*/	/*393:*/
case 125:
YY_RULE_SETUP
#line 349 "lexer.l"
return FONT;
	YY_BREAK
/*:393*/	/*424:*/
case 126:
YY_RULE_SETUP
#line 351 "lexer.l"
return CONTENT;
	YY_BREAK
/*:424*/
case 127:
YY_RULE_SETUP
#line 353 "lexer.l"
QUIT("Unexpected keyword '%s' in line %d",yytext,yylineno);
	YY_BREAK
case 128:
YY_RULE_SETUP
#line 354 "lexer.l"
QUIT("Unexpected character '%c' (0x%02X) in line %d",yytext[0]>' '?yytext[0]:' ',yytext[0],yylineno);
	YY_BREAK
case 129:
YY_RULE_SETUP
#line 356 "lexer.l"
ECHO;
	YY_BREAK
#line 2090 "lexer.c"
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(STR):
case YY_STATE_EOF(TXT):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
/* %% [14.0] code to do back-up for compressed tables and set up yy_cp goes here */
				yy_cp = (yy_last_accepting_cpos);
				yy_current_state = (yy_last_accepting_state);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of yylex */
/* %ok-for-header */

/* %if-c++-only */
/* %not-for-header */

/* %ok-for-header */

/* %endif */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
/* %if-c-only */
static int yy_get_next_buffer (void)
/* %endif */
/* %if-c++-only */
/* %endif */
{
    	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = (yytext_ptr);
	register int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			yy_size_t num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER_LVALUE;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				yy_size_t new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc((void *) b->yy_ch_buf,b->yy_buf_size + 2  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = 0;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart(yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) ((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

/* %if-c-only */
/* %not-for-header */

    static yy_state_type yy_get_previous_state (void)
/* %endif */
/* %if-c++-only */
/* %endif */
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    
/* %% [15.0] code to get the start state into yy_current_state goes here */
	yy_current_state = (yy_start);

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
/* %% [16.0] code to find the next state goes here */
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 388 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
/* %if-c-only */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
/* %endif */
/* %if-c++-only */
/* %endif */
{
	register int yy_is_jam;
    /* %% [17.0] code to find the next state, and perhaps do backing up, goes here */
	register char *yy_cp = (yy_c_buf_p);

	register YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 388 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 387);

		return yy_is_jam ? 0 : yy_current_state;
}

/* %if-c-only */

/* %endif */

/* %if-c-only */
#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

/* %endif */
/* %if-c++-only */
/* %endif */
{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			yy_size_t offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart(yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap( ) )
						return EOF;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

/* %% [19.0] update BOL and yylineno */
	if ( c == '\n' )
		   
    yylineno++;
;

	return c;
}
/* %if-c-only */
#endif	/* ifndef YY_NO_INPUT */
/* %endif */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
/* %if-c-only */
    void yyrestart  (FILE * input_file )
/* %endif */
/* %if-c++-only */
/* %endif */
{
    
	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer(yyin,YY_BUF_SIZE );
	}

	yy_init_buffer(YY_CURRENT_BUFFER,input_file );
	yy_load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
/* %if-c-only */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
/* %endif */
/* %if-c++-only */
/* %endif */
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

/* %if-c-only */
static void yy_load_buffer_state  (void)
/* %endif */
/* %if-c++-only */
/* %endif */
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
/* %if-c-only */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size )
/* %endif */
/* %if-c++-only */
/* %endif */
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
/* %if-c-only */
    void yy_delete_buffer (YY_BUFFER_STATE  b )
/* %endif */
/* %if-c++-only */
/* %endif */
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree((void *) b->yy_ch_buf  );

	yyfree((void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
/* %if-c-only */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )
/* %endif */
/* %if-c++-only */
/* %endif */

{
	int oerrno = errno;
    
	yy_flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

/* %if-c-only */

        b->yy_is_interactive = 0;
    
/* %endif */
/* %if-c++-only */
/* %endif */
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
/* %if-c-only */
    void yy_flush_buffer (YY_BUFFER_STATE  b )
/* %endif */
/* %if-c++-only */
/* %endif */
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state( );
}

/* %if-c-or-c++ */
/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
/* %if-c-only */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer )
/* %endif */
/* %if-c++-only */
/* %endif */
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}
/* %endif */

/* %if-c-or-c++ */
/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
/* %if-c-only */
void yypop_buffer_state (void)
/* %endif */
/* %if-c++-only */
/* %endif */
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}
/* %endif */

/* %if-c-or-c++ */
/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
/* %if-c-only */
static void yyensure_buffer_stack (void)
/* %endif */
/* %if-c++-only */
/* %endif */
{
	yy_size_t num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );
								  
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}
/* %endif */

/* %if-c-only */
/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer(b  );

	return b;
}
/* %endif */

/* %if-c-only */
/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (yyconst char * yystr )
{
    
	return yy_scan_bytes(yystr,strlen(yystr) );
}
/* %endif */

/* %if-c-only */
/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (yyconst char * yybytes, yy_size_t  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) yyalloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}
/* %endif */

/* %if-c-only */
    static void yy_push_state (int  new_state )
/* %endif */
/* %if-c++-only */
/* %endif */
{
    	if ( (yy_start_stack_ptr) >= (yy_start_stack_depth) )
		{
		yy_size_t new_size;

		(yy_start_stack_depth) += YY_START_STACK_INCR;
		new_size = (yy_start_stack_depth) * sizeof( int );

		if ( ! (yy_start_stack) )
			(yy_start_stack) = (int *) yyalloc(new_size  );

		else
			(yy_start_stack) = (int *) yyrealloc((void *) (yy_start_stack),new_size  );

		if ( ! (yy_start_stack) )
			YY_FATAL_ERROR( "out of memory expanding start-condition stack" );
		}

	(yy_start_stack)[(yy_start_stack_ptr)++] = YY_START;

	BEGIN(new_state);
}

/* %if-c-only */
    static void yy_pop_state  (void)
/* %endif */
/* %if-c++-only */
/* %endif */
{
    	if ( --(yy_start_stack_ptr) < 0 )
		YY_FATAL_ERROR( "start-condition stack underflow" );

	BEGIN((yy_start_stack)[(yy_start_stack_ptr)]);
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

/* %if-c-only */
static void yy_fatal_error (yyconst char* msg )
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}
/* %endif */
/* %if-c++-only */
/* %endif */

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/* %if-c-only */
/* %if-reentrant */
/* %endif */

/** Get the current line number.
 * 
 */
int yyget_lineno  (void)
{
        
    return yylineno;
}

/** Get the input stream.
 * 
 */
FILE *yyget_in  (void)
{
        return yyin;
}

/** Get the output stream.
 * 
 */
FILE *yyget_out  (void)
{
        return yyout;
}

/** Get the length of the current token.
 * 
 */
yy_size_t yyget_leng  (void)
{
        return yyleng;
}

/** Get the current token.
 * 
 */

char *yyget_text  (void)
{
        return yytext;
}

/* %if-reentrant */
/* %endif */

/** Set the current line number.
 * @param line_number
 * 
 */
void yyset_lineno (int  line_number )
{
    
    yylineno = line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * 
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  in_str )
{
        yyin = in_str ;
}

void yyset_out (FILE *  out_str )
{
        yyout = out_str ;
}

int yyget_debug  (void)
{
        return yy_flex_debug;
}

void yyset_debug (int  bdebug )
{
        yy_flex_debug = bdebug ;
}

/* %endif */

/* %if-reentrant */
/* %if-bison-bridge */
/* %endif */
/* %endif if-c-only */

/* %if-c-only */
static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    /* We do not touch yylineno unless the option is enabled. */
    yylineno =  1;
    
    (yy_buffer_stack) = 0;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = (char *) 0;
    (yy_init) = 0;
    (yy_start) = 0;

    (yy_start_stack_ptr) = 0;
    (yy_start_stack_depth) = 0;
    (yy_start_stack) =  NULL;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = (FILE *) 0;
    yyout = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}
/* %endif */

/* %if-c-only SNIP! this currently causes conflicts with the c++ scanner */
/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state();
	}

	/* Destroy the stack itself. */
	yyfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Destroy the start condition stack. */
        yyfree((yy_start_stack)  );
        (yy_start_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( );

/* %if-reentrant */
/* %endif */
    return 0;
}
/* %endif */

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size )
{
	return (void *) malloc( size );
}

void *yyrealloc  (void * ptr, yy_size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void yyfree (void * ptr )
{
	free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

/* %if-tables-serialization definitions */
/* %define-yytables   The name for this specific scanner's tables. */
#define YYTABLES_NAME "yytables"
/* %endif */

/* %ok-for-header */

#line 356 "lexer.l"


	/*:533*/

